@@ -25,7 +25,7 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 # from flexmock import * is evil, keep it from doing any damage
 __all__ = ['flexmock']
-__version__ = '0.10.5'
+__version__ = '0.10.6'
 
 
 import inspect
@@ -33,7 +33,6 @@ import re
 import sys
 import types
 
-
 AT_LEAST = 'at least'
 AT_MOST = 'at most'
 EXACTLY = 'exactly'
@@ -834,20 +833,27 @@ class Mock(object):
     def _update_method(self, expectation, name):
         method_instance = self._create_mock_method(name)
         obj = self._object
-        if _hasattr(obj, name) and not hasattr(expectation, 'original'):
-            expectation._update_original(name, obj)
-            method_type = type(_getattr(expectation, 'original'))
-            try:
-                # TODO(herman): this is awful, fix this properly.
-                # When a class/static method is mocked out on an *instance*
-                # we need to fetch the type from the class
-                method_type = type(_getattr(obj.__class__, name))
-            except:
-                pass
-            if method_type in SPECIAL_METHODS:
-                expectation.original_function = getattr(obj, name)
-            expectation.method_type = method_type
-        if not _isclass(obj) or expectation.method_type in SPECIAL_METHODS:
+        if _hasattr(obj, name):
+            if hasattr(expectation, 'original'):
+                expectation.method_type = type(_getattr(expectation, 'original'))
+            else:
+                expectation._update_original(name, obj)
+                method_type = type(_getattr(expectation, 'original'))
+                try:
+                    # TODO(herman): this is awful, fix this properly.
+                    # When a class/static method is mocked out on an *instance*
+                    # we need to fetch the type from the class
+                    method_type = type(_getattr(obj.__class__, name))
+                except:
+                    pass
+                if method_type in SPECIAL_METHODS:
+                    expectation.original_function = getattr(obj, name)
+                expectation.method_type = method_type
+        if (
+            not _isclass(obj)
+            or expectation.method_type in SPECIAL_METHODS
+            or name == '__new__'
+        ):
             method_instance = types.MethodType(method_instance, obj)
         override = _setattr(obj, name, method_instance)
         expectation._local_override = override
@@ -1246,7 +1252,9 @@ def _hook_into_pytest():
                 return ret
             if hasattr(runner.CallInfo, "from_call"):
                 teardown = runner.CallInfo.from_call(flexmock_teardown, when=when)
-                teardown.duration = ret.duration
+                if hasattr(runner.CallInfo, "duration"):
+                    # CallInfo.duration only available in Pytest 6+
+                    teardown.duration = ret.duration
             else:
                 teardown = runner.CallInfo(flexmock_teardown, when=when)
                 teardown.result = None
